<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/*---------------------------------*/ 
/* class  WizShop_Template_Loader  */
/*---------------------------------*/ 
class WizShop_Template_Loader {
	public function __construct() {
		add_filter('template_include', array($this, 'load_template' ) );
		add_action('wiz_single_product_init',array( $this, 'single_product_init'),10,1);
		add_action('wiz_archive_product_init',array( $this, 'archive_product_init'),10,1);
		add_action('wiz_cat_view_init',array( $this, 'cat_view_init'),10,1);
		add_action('wiz_search_product_init',array( $this, 'search_product_init'),10, 1);
		add_action('wiz_user_details_init',array( $this, 'user_details_init'),10,2);
		add_action('wiz_categories_init',array( $this, 'categories_init'),10);
		add_action('wp_head',array( $this, 'top_head'), 5);
		add_action('wp_head',array( $this, 'prepare_head'));
		add_filter('parse_query', array( $this, 'get_static_page')) ;
		if (!is_admin() ){
			add_filter('pll_the_language_link', array( $this, 'poly_lang_switch' ), 10, 2);
			add_filter('the_title', array( $this, 'clear_static_page_title'), 10, 2) ;
		}
		
		if (!is_admin()){
			add_filter('pll_get_current_language', array( $this, 'set_pll_lang' ));
		}
	}
		
	function load_template($template) {
	
		$template_names = array();
		$page = '';

		if ( is_page()) {
			$post = get_post();
			if( $post && function_exists('pll_get_post_language')){
				$p_lang = pll_get_post_language($post->ID);
				if(wizshop_is_shop_lang($p_lang)){
					wizshop_cur_lang($p_lang);
				}
			}
		} elseif ($tax = wizshop_is_cat_tax()) {
			wizshop_cur_lang($tax['lang']);
			$term = get_queried_object();
			$page = 'archive-product.php';	
			$template_names[] = wizshop_template_part($tax['lang']) . $page;
			$template_names[] = wizshop_template_part() . $page;
		} elseif ($pst = wizshop_product_archive_type()) {
			wizshop_cur_lang($pst['lang']);
			$page 	= (is_search()) ? 'search-product.php' : 'single-product.php';
			$template_names[] = wizshop_template_part($pst['lang']) . $page;
			$template_names[] = wizshop_template_part() . $page;
		} 
		if ( $page ) {
			$template = locate_template( $template_names );
			if (!$template)
				$template = wizshopPluginTemplate . '/' . $page;
		}
		return $template;
	}
	
	function prepare_head(){
		if (wizshop_is_cat_tax()) {
			do_action('wiz_archive_product_init',get_bloginfo('name') . ' | ' /*. get_taxonomy(get_query_var('taxonomy'))->labels->name . ' | '*/);
		} elseif (wizshop_product_archive_type()) {		
			if(is_search()){
				do_action('wiz_search_product_init', get_search_query());
			}else{
				do_action('wiz_single_product_init',get_bloginfo('name') . ' | ' /*. get_post_type_object(get_query_var('post_type'))->labels->name . ' | '*/);
			}
		}
		else if(get_post_type() == 'page'){
			if(wizshop_single_product_page()){
				do_action('wiz_single_product_init',get_bloginfo('name') . ' | ' /*. get_post_type_object(get_query_var('post_type'))->labels->name . ' | '*/);
			}else if(wizshop_archive_product_page()){
				do_action('wiz_archive_product_init',get_bloginfo('name') . ' | ' /*. get_taxonomy(get_query_var('taxonomy'))->labels->name . ' | '*/);
			}else if(wizshop_search_product_page()){
				global $wp_query;
				do_action('wiz_search_product_init', isset($wp_query->query["s"]) ? $wp_query->query["s"] :"");
			}else if(wizshop_new_user_details_page()){
				do_action('wiz_user_details_init',get_bloginfo('name') . ' | ', __('Create account',WizShop));
			}
		}
	}
	
	function top_head(){
		$view_op = wizshop_get_view_options();
		echo '<script type="text/javascript">
					window["__wizshop_vc_config"] = window["__wizshop_vc_config"] ||
						{default_image: ' . json_encode(wizshop_def_image_name()).
						 ',ex_item_url: ' . json_encode(0 !=(8 & $view_op['doc_title'])).
						 ',ex_meta_desc: ' . json_encode(0 !=(4 & $view_op['doc_title'])).
						'};</script>
				<style data-wiz-css="" type="text/css">[data-wizshop]{visibility:hidden;}</style>
				<style data-wiz-def-css="" type="text/css">.v_ihide, .hide0, .hiderev1 {display:none !important;}</style>
				';
	}

	function archive_product_init($title) {
		if(isset($title)) {
			$op = wizshop_get_view_options();
			if($op['doc_title'] & 1){
				echo '<div id="wizshop-doc-title" data-wiz-doc-title data-wizshop>' .esc_html($title) .'{{Title}}</div>';
			}
		}
		$term = get_queried_object();
		$cat_info = false;
		if(!is_object($term) || is_wp_error($term) || !wizshop_is_cat_tax($term->taxonomy)){
			global $wizshop_cat_taxonomies;
			$cat_key = get_query_var($wizshop_cat_taxonomies[wizshop_cur_lang()]['name']);
			if(isset($cat_key)) {
				$cat_info  = WizShop_Categories::get_cat_info_by_key($cat_key, $wizshop_cat_taxonomies[wizshop_cur_lang()]['name']);
			}
		}else{
			$cat_info = WizShop_Categories::get_cat_info($term->taxonomy,$term->term_id);
		} 
		if($cat_info) {
			$this->set_cat_info_script($cat_info, wizshop_grid_view());
		}
	}
	
	function cat_view_init() {
		$cat_info = WizShop_Categories::get_cat_info_by_key(wizshop_get_filter_var());
		$this->set_cat_info_script($cat_info, wizshop_grid_view());
	}
	
	function set_cat_info_script($cat_info, $view_type_def){
		if(!$cat_info) return;
		echo '<script type="text/javascript">
				_vsc_static_cat_json.cat.path = "'. esc_js($cat_info->cat_path). '"; 
				_vsc_static_cat_json.cat.name = "' . esc_js($cat_info->cat) .'";
				window["vshop_cat_view_json"] = '. json_encode(wizshop_cat_view_options(false,$cat_info,$view_type_def)). 
				';</script>';
	}
	
	function single_product_init($title) {
		if(isset($title)) {
			$op = wizshop_get_view_options();
			if($op['doc_title'] & 2){
				echo '<div id="wizshop-doc-title" data-wiz-doc-title data-wizshop>' .esc_html($title) .'{{Title}}</div>';
			}
		}
		$p_id = wizshop_product_tag_var();
		if(isset($p_id)) {
			echo '<script type="text/javascript">
				_vsc_static_item_json.item = "'. rawurldecode($p_id). 
				'";</script>';
		}
	}
	
	function search_product_init($text) {
		if(isset($text)) {
			echo '<script type="text/javascript">
				_vsc_static_query_json.text = "'. esc_js($text). '";' .
				'window["vshop_cat_view_json"] = '. json_encode(wizshop_cat_view_options(true/*all*/,null,wizshop_search_view_cookie_val())). 
				';</script>';
		}
	}
	
	function user_details_init($home,$new_title) {
		if(isset($new_title)) {
			echo '<div data-wiz-doc-title data-wizshop>' .esc_html($home) .'{{Title}}</div>';
			echo '<script type="text/javascript">
				_vsc_static_title_json.text = "'. esc_js($new_title). 
				'";</script>';
		}
	}	

	function categories_init() {
		echo '<script type="text/javascript">
			_vsc_static_cat_paint_json.init=true;
			</script>';
	}
	
	function set_pll_lang($lang){
		$new_lang = '';
		if(!$lang){
			if ($pst = wizshop_product_archive_type()) {
				$new_lang = $pst['lang'];
			}
		}
		if($new_lang && function_exists('pll_languages_list')){
			$listlanguages = PLL()->model->get_languages_list(array('hide_empty' => false));
			foreach ($listlanguages as $language) {
				if($language->slug == $new_lang){
					 $lang = $language;
					 break;
				}
			}
		}
		return $lang;
	}

	function get_static_page($query){	
		if ($tax = wizshop_is_cat_tax()){
			$sp = WizShop_Pages::get_page_id('archive-product', $tax["lang"]);
			if($sp != -1){
				$pst = get_post($sp);
				$query->query["post_type"] = $tax["name"];
				$query->query["pagename"] = $pst->post_title;
				$query->set('page','');
				$query->set('pagename', $pst->post_title);
				$query->queried_object = $pst;
				$query->queried_object_id = $sp;
				$query->queried_terms = null;
				$query->tax_query = null;
				$query->is_archive = false;
				$query->is_page = true;
				$query->is_single = false;
				$query->is_tax = false;
				$query->is_singular =true;
				$query->is_post_type_archive = false;
			}	
		}else if($ap = wizshop_product_archive_type()){
			$page =  is_search() ? 'search-product' : 'single-product';
			$sp = WizShop_Pages::get_page_id($page, $ap["lang"]);
			if($sp != -1){
				$query->query["post_type"] =  $ap["name"];
				if(is_search()) {
					unset($query->query_vars["s"]);
				}
				$pst = get_post($sp);
				$query->query["pagename"] = $pst->post_title;
				$query->set('page','');
				$query->set('post_type', 'page' );
				$query->set('pagename', $pst->post_title);
				$query->queried_object = $pst;
				$query->queried_object_id = $sp;
				$query->is_archive 	= false;
				$query->is_page 	= true;
				$query->is_single 	= false;
				$query->is_tax 		= false;
				$query->is_singular = true;
				$query->is_search	= false;
				$query->is_post_type_archive = false;
			}
		}
	}
	
	function poly_lang_switch($url, $lang) {
		global $wp_query;
		global $wizshop_is_multi_lang;
		if($wizshop_is_multi_lang && wizshop_is_shop_lang($lang)){
			if(null == $url){
				if(wizshop_is_cat_tax()){
					if(function_exists('pll_get_term_translations')){
						$term = get_queried_object();
						if(is_object($term)) {
							$term_op = pll_get_term_translations($term->term_id);
							if(isset($term_op) && is_array($term_op) && isset($term_op[$lang])){
								$url = get_term_link($term_op[$lang]);
							}
						}
					}
				} elseif (wizshop_product_archive_type() && ($prod_url = wizshop_get_products_url($lang)) ) {
					$p_id = wizshop_product_tag_var();
					$url = trailingslashit($prod_url) . (isset($p_id) ? $p_id :"") ;
				}
			}else if($pt = wizshop_template_page_orig_posttype()){

				if(wizshop_is_product_posttype($pt)){
					if(isset($wp_query->query[wizshop_product_tag])){
						$url = trailingslashit( wizshop_get_products_url($lang)) . wizshop_check_product_var($wp_query->query[wizshop_product_tag]) ;
					}else if(isset($wp_query->query["s"])){
						$url = trailingslashit( wizshop_get_products_url($lang)) . "?s=". $wp_query->query["s"] ;
					}
				}else if($tax = wizshop_is_cat_tax($pt)){
					$url= null;
					if(function_exists('pll_get_term_translations')){
						$cat_slug = get_query_var($tax["name"]);
						if(isset($cat_slug)) {
							$info  = WizShop_Categories::get_term_by_slug($cat_slug, $tax["name"]);
							if($info){
								$term_op = pll_get_term_translations($info[0]);
								if(isset($term_op) && is_array($term_op) && isset($term_op[$lang])){
									$url = trailingslashit(get_term_link($term_op[$lang])) ;
								}
							}
						}		
					}
				}
			}
		}
		return $url;
	}

	function clear_static_page_title($title, $id){	
		global $post;
		if(isset($post) && $id == $post->ID){
			if(wizshop_is_template_page($id)){
				$title = "";
			}
		}
		return $title;
	}


}
new WizShop_Template_Loader();
?>